@@ -18,7 +18,6 @@ import itertools
 
 import cloudkitty.api.app
 import cloudkitty.collector.gnocchi
-import cloudkitty.collector.monasca
 import cloudkitty.collector.prometheus
 import cloudkitty.config
 import cloudkitty.fetcher
@@ -44,8 +43,6 @@ _opts = [
         cloudkitty.collector.collect_opts))),
     ('collector_gnocchi', list(itertools.chain(
         cloudkitty.collector.gnocchi.collector_gnocchi_opts))),
-    ('collector_monasca', list(itertools.chain(
-        cloudkitty.collector.monasca.collector_monasca_opts))),
     ('collector_prometheus', list(itertools.chain(
         cloudkitty.collector.prometheus.collector_prometheus_opts))),
     ('fetcher', list(itertools.chain(
