@@ -23,8 +23,8 @@ Create Date: 2015-03-17 17:50:15.229896
 revision = '385e33fef139'
 down_revision = '2ac2217dcbd9'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+import sqlalchemy as sa  # noqa: E402
 
 
 def upgrade():
