@@ -13,20 +13,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-# @author: Martin CAMEY
-#
 from oslo_config import cfg
 
 from cloudkitty import fetcher
 
+FETCHER_SOURCE_OPTS = 'fetcher_source'
 
-SOURCE_FETCHER_OPTS = 'source_fetcher'
-source_fetcher_opts = [
-    cfg.ListOpt('sources',
-                default=list(),
-                help='list of source identifiers'), ]
+fetcher_source_opts = [
+    cfg.ListOpt(
+        'sources',
+        default=list(),
+        help='list of source identifiers',
+    ),
+]
+
+cfg.CONF.register_opts(fetcher_source_opts, FETCHER_SOURCE_OPTS)
 
-cfg.CONF.register_opts(source_fetcher_opts, SOURCE_FETCHER_OPTS)
 CONF = cfg.CONF
 
 
@@ -36,4 +38,4 @@ class SourceFetcher(fetcher.BaseFetcher):
     name = 'source'
 
     def get_tenants(self):
-        return CONF.source_fetcher.sources
+        return CONF.fetcher_source.sources
