@@ -13,7 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-import mock
+from unittest import mock
 
 from cloudkitty.db import api as ck_db_api
 from cloudkitty import tests
